@@ -341,12 +341,11 @@ def fup_customer(customer_name):
                     CONFIG['AIGUILLIER']['password']
                 )
             )
-            if (
-                    response.status_code == 200
-                    and response.json()['status'] == '200'
-            ):
+            if response.status_code == 200:
                 fuped = True
                 break
+            else:
+                raise ValueError(response.text)
         except Exception as e:
             LOGS.logger.warning(
                 "[FUP] Try {} out of 3. "
@@ -385,12 +384,11 @@ def defup_customer(customer_name):
                     CONFIG['AIGUILLIER']['password']
                 )
             )
-            if (
-                    response.status_code == 200
-                    and response.json()['status'] == '200'
-            ):
+            if response.status_code == 200 or response.status_code == 409:
                 defuped = True
                 break
+            else:
+                raise ValueError(response.text)
         except Exception as e:
             LOGS.logger.warning(
                 "[DEFUP] Try {} out of 3. "
