@@ -914,135 +914,144 @@ class Customer(object):
             info['total'] = round(total / 1000000000, 2)
             info['octets_in'] = round(octets_in / 1000000000, 2)
             info['octets_out'] = round(octets_out / 1000000000, 2)
-            url = core.database_url(**FUPDB_CREDENTIALS)
-            with records.Database(url) as db:
-                sql = (
-                    "SELECT status FROM fup "
-                    "WHERE customer=:name "
-                    "AND policy=:policy "
-                    "ORDER BY datetime DESC LIMIT 1"
-                    )
-                rows = db.query(sql, name=self.name, policy=info['name'])
-                row = rows.first()
-                if row:
-                    status = row.status
-                else:
-                    status = False
-                LOGS.logger.info(
-                    "Customer {} fup status in SI database: {}"
-                    .format(self.name, status)
-                )
-            if info['total'] >= info['data_limit'] and not status:
-                info['fup_in'] = True
-            elif info['total'] < info['data_limit'] and status:
-                info['fup_out'] = True
-            if for_real:
-                # FUP the customer in Aiguiller
-                if info.get('fup_in'):  # à limiter
-                    LOGS.logger.info(
-                        "> FUP-ing Customer '{}'...".format(self.name)
-                    )
-                    if info['period'] == 'try':
-                        params['actif'] = 'FALSE'
-                    else:
-                        params['period'] = info['period']
-                    params['customer'] = self.name
-                    self.fup_defup(
-                        'post',
-                        params,
-                        info['name'],
-                        True,
-                        str(info['total']),
-                        str(info['period']),
-                        'Fup'
+
+            # customers that are not in db should not be considered
+            customer_exists = core.get_customers_si(
+                identifier="name",
+                value=self.name
+            )
+            if customer_exists:
+                url = core.database_url(**FUPDB_CREDENTIALS)
+                with records.Database(url) as db:
+                    sql = (
+                        "SELECT status FROM fup "
+                        "WHERE customer=:name "
+                        "AND policy=:policy "
+                        "ORDER BY datetime DESC LIMIT 1"
                         )
-                    """url = core.database_url(**FUPDB_CREDENTIALS)
-                    with records.Database(url) as db:
-                        sql = (
-                            "INSERT INTO fup "
-                            "(customer, product, policy, datetime, status, "
-                            "conso) "
-                            "VALUES "
-                            "(:name, :product, :policy, :date_time, :status, "
-                            ":conso)"
-                            )
-                        db.query(
-                            sql,
-                            name=self.name,
-                            product=self.product.name,
-                            policy=info['name'],
-                            date_time=datetime.now(),
-                            status=True,
-                            conso=str(info['total'])
-                            )
-                    if info['period'] == 'try':
-                        params['actif'] = FALSE
+                    rows = db.query(sql, name=self.name, policy=info['name'])
+                    row = rows.first()
+                    if row:
+                        status = row.status
                     else:
-                        params['period'] = info['period']
-                    params['customer'] = self.name
-                    REST_CLIENT.post(
-                        '/fup',
-                        auth=(
-                            CONFIG['AIGUILLIER']['username'],
-                            CONFIG['AIGUILLIER']['password']
-                            ),
-                        params=params
-                        )
-                    """
-                # DEFUP the customer in Aiguiller
-                elif info.get('fup_out'):  # libérer
+                        status = False
                     LOGS.logger.info(
-                        "> DEFUP-ing Customer '{}'...".format(self.name)
+                        "Customer {} fup status in SI database: {}"
+                        .format(self.name, status)
                     )
-                    if info['period'] == 'try':
-                        params['actif'] = 'TRUE'
-                        method = 'post'
-                    else:
-                        params['period'] = info['period']
-                        method = 'delete'
+                if info['total'] >= info['data_limit'] and not status:
+                    info['fup_in'] = True
+                elif info['total'] < info['data_limit'] and status:
+                    info['fup_out'] = True
+
+                if for_real:
+                    # FUP the customer in Aiguiller
+                    if info.get('fup_in'):  # à limiter
+                        LOGS.logger.info(
+                            "> FUP-ing Customer '{}'...".format(self.name)
+                        )
+                        if info['period'] == 'try':
+                            params['actif'] = 'FALSE'
+                        else:
+                            params['period'] = info['period']
                         params['customer'] = self.name
                         self.fup_defup(
-                            method,
+                            'post',
                             params,
                             info['name'],
-                            False,
+                            True,
                             str(info['total']),
                             str(info['period']),
-                            'Defup'
+                            'Fup'
                             )
-                    """url = core.database_url(**FUPDB_CREDENTIALS)
-                    with records.Database(url) as db:
-                        sql = (
-                            "INSERT INTO fup "
-                            "(customer, product, policy, datetime, status, "
-                            "conso) "
-                            "VALUES "
-                            "(:name, :product, :policy, :date_time, :status, "
-                            ":conso)"
+                        """url = core.database_url(**FUPDB_CREDENTIALS)
+                        with records.Database(url) as db:
+                            sql = (
+                                "INSERT INTO fup "
+                                "(customer, product, policy, datetime, status,"
+                                "conso) "
+                                "VALUES "
+                                "(:name, :product, :policy, :date_time, :status,"
+                                ":conso)"
+                                )
+                            db.query(
+                                sql,
+                                name=self.name,
+                                product=self.product.name,
+                                policy=info['name'],
+                                date_time=datetime.now(),
+                                status=True,
+                                conso=str(info['total'])
+                                )
+                        if info['period'] == 'try':
+                            params['actif'] = FALSE
+                        else:
+                            params['period'] = info['period']
+                        params['customer'] = self.name
+                        REST_CLIENT.post(
+                            '/fup',
+                            auth=(
+                                CONFIG['AIGUILLIER']['username'],
+                                CONFIG['AIGUILLIER']['password']
+                                ),
+                            params=params
                             )
-                        db.query(
-                            sql,
-                            name=self.name,
-                            product=self.product.name,
-                            policy=info['name'],
-                            date_time=datetime.now(),
-                            status=False,
-                            conso=str(info['total'])
-                            )
-                    if info['period'] == 'try':
-                        params['actif'] = TRUE
-                    else:
-                        params['period'] = info['period']
-                    params['customer'] = self.name
-                    REST_CLIENT.delete(
-                        '/fup',
-                        auth=(
-                            CONFIG['AIGUILLIER']['username'],
-                            CONFIG['AIGUILLIER']['password']
-                            ),
-                        params=params
+                        """
+                    # DEFUP the customer in Aiguiller
+                    elif info.get('fup_out'):  # libérer
+                        LOGS.logger.info(
+                            "> DEFUP-ing Customer '{}'...".format(self.name)
                         )
-                    """
+                        if info['period'] == 'try':
+                            params['actif'] = 'TRUE'
+                            method = 'post'
+                        else:
+                            params['period'] = info['period']
+                            method = 'delete'
+                            params['customer'] = self.name
+                            self.fup_defup(
+                                method,
+                                params,
+                                info['name'],
+                                False,
+                                str(info['total']),
+                                str(info['period']),
+                                'Defup'
+                                )
+                        """url = core.database_url(**FUPDB_CREDENTIALS)
+                        with records.Database(url) as db:
+                            sql = (
+                                "INSERT INTO fup "
+                                "(customer, product, policy, datetime, status, "
+                                "conso) "
+                                "VALUES "
+                                "(:name, :product, :policy, :date_time, :status, "
+                                ":conso)"
+                                )
+                            db.query(
+                                sql,
+                                name=self.name,
+                                product=self.product.name,
+                                policy=info['name'],
+                                date_time=datetime.now(),
+                                status=False,
+                                conso=str(info['total'])
+                                )
+                        if info['period'] == 'try':
+                            params['actif'] = TRUE
+                        else:
+                            params['period'] = info['period']
+                        params['customer'] = self.name
+                        REST_CLIENT.delete(
+                            '/fup',
+                            auth=(
+                                CONFIG['AIGUILLIER']['username'],
+                                CONFIG['AIGUILLIER']['password']
+                                ),
+                            params=params
+                            )
+                        """
+
         return cdrs_by_policies
 
     def get_cdr_summary(
